package TexturedSphere;
/*
 * This code was developed by the CTS team at NASA's Johnson Space Center.
 * CTS is the Flight Design and Dynamics Division's (Code DM) Core Trajectory
 * Subsystem.
 *
 * Copyright information can be found at the top level of the CTS source
 * distribution in the file "copyrights.txt".
 *
 * Disclaimer information can be found at the top level of the CTS source
 * distribution in the file "disclaimers.txt".
 */

import javax.swing.*;
import java.awt.event.KeyAdapter;
import java.awt.event.KeyEvent;


/**
 * This class handles the key events. It extends the KeyAdapter Class.
 * <p>
 *
 * @version $Id: KeyHandler.java 215 2008-02-22 21:46:31Z bkubena $
 * @since CTS 1.0
 */
class KeyHandler extends KeyAdapter {
    
    /** Version identifier that will be present in the generated class file. */
    public static final String VERSION_STRING =
        "@(#)$Id: KeyHandler.java 215 2008-02-22 21:46:31Z bkubena $"; 
    
    /** Debugging Flag - invoked using: java -Ddebugging=true <MainClass>  */
    private static boolean _debug = Boolean.getBoolean("debugging")
                                  ||Boolean.getBoolean("nasaops.cts.display.jogl.earth3d")
                                  ||Boolean.getBoolean("KeyHandler.debugging");     
    
    /** The Renderer object on which key events are to act */
    private Renderer renderer;
    
    /** Flag used for tracking ctrl-<key> combos */
    private boolean _ctrlActive = false;
    
    /**
     * Default Constructor that accepts the render for call back purposes as
     * well as the originating JPanel object
     * 
     * 
     * @param renderer A Renderer object used for callbacks
     * @param thePanel A EarthLightTest (JPanel) object used for callbacks
     */
    public KeyHandler( Renderer renderer ) {
        this.renderer = renderer;
    }
     
    /**
     * Checks if a key is typed.  This method currently does not respond to 
     * this event
     *
     * @param e A key typed event
     */
    public void keyTyped( KeyEvent e ) {
        // Nothing
    }

    /**
     * Checks if a key is pressed and calls the appropriate method to process
     * the event.
     *
     * @param e A key pressed event
     */
    public void keyPressed( KeyEvent e ) {
        processKeyEvent(e, true);
    }
    
    /**
     * Checks if a key is released.  This method currently does not respond to 
     * this event
     *
     * @param e A key released event
     */
    public void keyReleased( KeyEvent e ) {
        // Nothing
    }

    /**
     * Process the key events that are sensed.
     *
     * @param e A key event
     * @param pressed Flag signifying whether the key has been pressed or not
     */
    private void processKeyEvent( KeyEvent e, boolean pressed ) {
        //System.out.println("Processing KeyEvent..."+e.getKeyCode());
        
        switch (e.getKeyCode()) {    
            case KeyEvent.VK_PAGE_UP:
                renderer.moveLightXYZ(1,   0.25f);
                break;  
            case KeyEvent.VK_PAGE_DOWN:
                renderer.moveLightXYZ(1,  -0.25f);
                break;  
                
            case KeyEvent.VK_RIGHT:
                renderer.moveLightXYZ(2,   0.25f);
                break;
            case KeyEvent.VK_LEFT:
                renderer.moveLightXYZ(2,  -0.25f);
                break;                
                
            case KeyEvent.VK_UP:
                renderer.moveLightXYZ(3,   0.25f);
                break;
            case KeyEvent.VK_DOWN:
                renderer.moveLightXYZ(3,  -0.25f);
                break;
                
            case KeyEvent.VK_OPEN_BRACKET:
                renderer.scale(0.9f);
                break;
            case KeyEvent.VK_CLOSE_BRACKET:
                renderer.scale(1.1f);
                break;
               
            case KeyEvent.VK_COMMA:
                renderer.decreaseTess();
                break;
            case KeyEvent.VK_PERIOD:
                renderer.increaseTess();
                break;                
                
                
            case KeyEvent.VK_W:
                renderer.toggleWireframe();
                break;
                
            case KeyEvent.VK_P:                  
                renderer.setLightType(!renderer.getLightType());
                
                if (renderer.getLightType()) {
                    System.out.println("Light Type: INFINITE");
                } else {
                    System.out.println("Light Type: POINT");
                }   
                
                break;
                
            case KeyEvent.VK_S:                 
                renderer.setShadeModel(!renderer.getShadeModel());
                
                if (renderer.getShadeModel()) {
                    System.out.println("Shade Model: SMOOTH");
                } else {
                    System.out.println("Shade Model: FLAT");
                }  
                
                break;
                
            case KeyEvent.VK_T:
                renderer.setTextureStatus(!renderer.getTextureStatus());
                
                if (renderer.getTextureStatus()) {
                    System.out.println("Textures: ON");
                } else {
                    System.out.println("Textures: OFF");
                }
                                
                break;
                
            default:
        }
    }
}